/*
** $Id: exec_shell.h,v 1.2 2020/09/11 21:16:41 lpitcher Exp lpitcher $
**
*/
#ifndef EXEC_SHELL_H
#define EXEC_SHELL_H	"$Revision: 1.2 $"

/*
** MACROs passed to or returned by exec_shell functions:
**
**	RUNERROR	unique PREP/Target/POST termination value
**			indicating internal processing error
*/
#define RUNERROR	(-1)

/*
** exec_shell public functions
**
** 	doExec()	fork off child to run script from shell
**			capture child's stdout & stderr and log them to syslog
**			Accepts: a char pointer to interpreter path
**				 a char pointer to target script
**			Updates: syslog with startup, termination, stdout & stderr messages
**			Returns: RUNERROR if child cannot be run, or
**				 child status code, if child was run
**
** 	doExit()	selects (based on the lockname) a script in /usr/local/libexec/rmonitor
**			and runs it, passing it the order parameter.
**			Accepts: a char pointer to resource name
**				 a char pointer to exit function
**			Updates: syslog with startup, termination, stdout & stderr messages
**			Returns: RUNERROR if exit script failed to execute
**				 script exit status (0 to 127) if exit script was executed
*/
int doExec(char *, char *);
int doExit(char *, char *);

#endif
/*
** Copyright Lew Pitcher (lew.pitcher@digitalfreehold.ca) February, 2013
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License version 2 as
** published by the Free Software Foundation.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License along
** with this program (see the licence.txt file); if not, write to the Free
** Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
** 02110-1301 USA.
*/
