/*
** $Id: process.h,v 1.1 2015/05/22 00:58:09 lpitcher Exp $
**
*/
#ifndef PROCESS_H
#define PROCESS_H "$Revision: 1.1 $"

/*
** MACROs returned by process functions:
**
**	PROC_WORKED	returned by doPrep()/doPost() when resource exit
**			completed successfully
**
**	PROC_FAILED	returned by doPrep()/doPost() when resource exit
**			failed completion, or could not be executed
**
*/
#define PROC_WORKED		1
#define PROC_FAILED		0

/*
** Public functions
**
**	doPrep()	fork off child process to execute "preprocessing" function  of specified resource
**			Accepts: a char pointer to resource name string
**				 an int value for semaphore file fd
**			Updates: syslog with child startup, stdout & stderr, termination messages
**				 related lock file (locked & unlocked) while synchronizing preprocessing function
**				 related semaphore file with updated "in use" count 
**			Returns: PROC_WORKED if preprocessing function completed successfully, or
**				 PROC_FAILED if preprocessing function failed, or doPrep() failed to invoke function
**
**	doPost()	fork off child process to execute "postprocessing" function of specified resource
**			Accepts: a char pointer to resource name string
**				 an int value for semaphore file fd
**			Updates: syslog with child startup, stdout & stderr, termination messages
**				 related lock file (locked & unlocked) while synchronizing postprocessing function
**				 related semaphore file with updated "in use" count 
**			Returns: PROC_WORKED if postprocessing function completed successfully, or
**				 PROC_FAILED if postprocessing function failed, or doPost() failed to invoke function
*/
int doPrep(char *,int);	/* invoke Resource Preprocessing exit */
int doPost(char *,int);	/* invoke Resource Postprocecssing exit */

#endif
/*
** Copyright Lew Pitcher (lew.pitcher@digitalfreehold.ca) February, 2013
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License version 2 as
** published by the Free Software Foundation.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License along
** with this program (see the licence.txt file); if not, write to the Free
** Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
** 02110-1301 USA.
*/
