/*
** $Id: sem_util.c,v 1.2 2020/07/11 22:12:13 lpitcher Exp $
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <unistd.h>

#include "sem_util.h"

/*
** getCount()	retrieves a five-character value from the provided fd
**		and converts it to an integer value
**
** Accepts:	an integer representing a Unix FD
**
** Updates:	nothing
**
** Returns:	-1 if value not a 5-digit integer
**		value (0 to 99999) of the contents of the file
*/
int getCount(int fd)
{
  char buf[5];
  int digit, count;

  read(fd,buf,1);
  lseek(fd,(off_t)0,SEEK_SET);

  switch (read(fd,buf,5))
  {
    case 0:
      memcpy(buf,"00000",5);
    case 5:
      break;

    default:
      memcpy(buf,"ABORT",5);
      break;
  }

  for (digit = count = 0; digit < 5; ++digit)
    if (buf[digit] >= '0' && buf[digit] <= '9')
      count = (count * 10) + (buf[digit] - '0');
    else break;

  if (digit != 5) count = COUNTERROR ;

  return count;
}

/*
** putCount()	writes a five-digit value to the indicated FD
**
** Accepts:	an integer representing a Unix FD
**		an integer representing the value to be written
**
** Updates:	the file associated with the FD
**
** Returns:	nothing
*/
void putCount(int fd, int count)	/* -ve count values are saved as zero */
{
  char buf[5];
  int digit;

  if (count < 0) count = 0;

  for (digit = 4; digit >= 0; --digit)
  {
    buf[digit] = '0' + (count % 10);
    count = count / 10;
  }
  putBuffer(fd,buf);
}

/*
** putBuffer()	writes a five-character value to the indicated FD
**
** Accepts:	an integer representing a Unix FD
**		an pointer to a five-character buffer
**
** Updates:	the file associated with the FD
**
** Returns:	nothing
*/
void putBuffer(int fd, char buffer[5])
{
  lseek(fd,0l,SEEK_SET);
  write(fd,buffer,5);
}


/*
** Copyright Lew Pitcher (lew.pitcher@digitalfreehold.ca) February, 2013
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License version 2 as
** published by the Free Software Foundation.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License along
** with this program (see the licence.txt file); if not, write to the Free
** Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
** 02110-1301 USA.
*/

